==> uimaj-3.2.0-source-release.zip: uimaj-3.2.0/uimaj-cpe/src/main/java/org/apache/uima/collection/impl/metadata/cpe/CpeTimerImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.collection.impl.metadata.cpe;

import org.apache.uima.collection.metadata.CpeDescriptorException;
import org.apache.uima.collection.metadata.CpeTimer;


/**
 * This class provides an API to plug in custom timers.
 * 
 */
public class CpeTimerImpl implements CpeTimer {
  
  /**
   * Instantiates a new cpe timer impl.
   */
  private CpeTimerImpl() {
  }

  /** The timer. */
  private String timer;

  /**
   * Instantiates a new cpe timer impl.
   *
   * @param aTimerClass the a timer class
   */
  public CpeTimerImpl(String aTimerClass) {
    timer = aTimerClass;
  }

  /*
   * (non-Javadoc)
   * 
   * @see org.apache.uima.collection.metadata.CpeTimer#set(java.lang.String)
   */
  @Override
  public void set(String aTimerClass) throws CpeDescriptorException {
    timer = aTimerClass;
  }

  /*
   * (non-Javadoc)
   * 
   * @see org.apache.uima.collection.metadata.CpeTimer#get()
   */
  @Override
  public String get() {
    return timer;
  }

}

==> uimaj-3.4.1-source-release.zip: uimaj-3.4.1/uimaj-cpe/src/main/java/org/apache/uima/collection/impl/metadata/cpe/CpeTimerImpl.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.collection.impl.metadata.cpe;

import org.apache.uima.collection.metadata.CpeDescriptorException;
import org.apache.uima.collection.metadata.CpeTimer;

/**
 * This class provides an API to plug in custom timers.
 * 
 */
public class CpeTimerImpl implements CpeTimer {

  /**
   * Instantiates a new cpe timer impl.
   */
  private CpeTimerImpl() {
  }

  /** The timer. */
  private String timer;

  /**
   * Instantiates a new cpe timer impl.
   *
   * @param aTimerClass
   *          the a timer class
   */
  public CpeTimerImpl(String aTimerClass) {
    timer = aTimerClass;
  }

  /*
   * (non-Javadoc)
   * 
   * @see org.apache.uima.collection.metadata.CpeTimer#set(java.lang.String)
   */
  @Override
  public void set(String aTimerClass) throws CpeDescriptorException {
    timer = aTimerClass;
  }

  /*
   * (non-Javadoc)
   * 
   * @see org.apache.uima.collection.metadata.CpeTimer#get()
   */
  @Override
  public String get() {
    return timer;
  }

}
